==> chromium_90.0.4430.212.orig.tar.xz: chromium-90.0.4430.212/ash/shelf/back_button.h <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_SHELF_BACK_BUTTON_H_
#define ASH_SHELF_BACK_BUTTON_H_

#include <memory>

#include "ash/ash_export.h"
#include "ash/shelf/shelf_button_delegate.h"
#include "ash/shelf/shelf_control_button.h"
#include "base/macros.h"

namespace ash {

class ShelfButtonDelegate;

// The back button shown on the shelf when tablet mode is enabled. Its opacity
// and visiblity are handled by its parent, ShelfView, to ensure the fade
// in/out of the icon matches the movement of ShelfView's items.
class ASH_EXPORT BackButton : public ShelfControlButton,
                              public ShelfButtonDelegate {
 public:
  static const char kViewClassName[];

  explicit BackButton(Shelf* shelf);
  ~BackButton() override;

  // Called when a locale change is detected. Updates the button tooltip and
  // accessible name.
  void HandleLocaleChange();

  // views::Button:
  void PaintButtonContents(gfx::Canvas* canvas) override;
  const char* GetClassName() const override;
  base::string16 GetTooltipText(const gfx::Point& p) const override;

  // views::View:
  void OnThemeChanged() override;

  // ShelfButtonDelegate:
  void OnShelfButtonAboutToRequestFocusFromTabTraversal(ShelfButton* button,
                                                        bool reverse) override;

  void ButtonPressed(views::Button* sender,
                     const ui::Event& event,
                     views::InkDrop* ink_drop) override;

 private:
  DISALLOW_COPY_AND_ASSIGN(BackButton);
};

}  // namespace ash

#endif  // ASH_SHELF_BACK_BUTTON_H_

==> chromium_102.0.5005.61.orig.tar.xz: chromium-102.0.5005.61/ash/shelf/back_button.h <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_SHELF_BACK_BUTTON_H_
#define ASH_SHELF_BACK_BUTTON_H_

#include <memory>

#include "ash/ash_export.h"
#include "ash/shelf/shelf_button_delegate.h"
#include "ash/shelf/shelf_control_button.h"

namespace ash {

class ShelfButtonDelegate;

// The back button shown on the shelf when tablet mode is enabled. Its opacity
// and visiblity are handled by its parent, ShelfView, to ensure the fade
// in/out of the icon matches the movement of ShelfView's items.
class ASH_EXPORT BackButton : public ShelfControlButton,
                              public ShelfButtonDelegate {
 public:
  static const char kViewClassName[];

  explicit BackButton(Shelf* shelf);

  BackButton(const BackButton&) = delete;
  BackButton& operator=(const BackButton&) = delete;

  ~BackButton() override;

  // Called when a locale change is detected. Updates the button tooltip and
  // accessible name.
  void HandleLocaleChange();

  // views::Button:
  void PaintButtonContents(gfx::Canvas* canvas) override;
  const char* GetClassName() const override;
  std::u16string GetTooltipText(const gfx::Point& p) const override;

  // views::View:
  void OnThemeChanged() override;

  // ShelfButtonDelegate:
  void OnShelfButtonAboutToRequestFocusFromTabTraversal(ShelfButton* button,
                                                        bool reverse) override;

  void ButtonPressed(views::Button* sender,
                     const ui::Event& event,
                     views::InkDrop* ink_drop) override;
};

}  // namespace ash

#endif  // ASH_SHELF_BACK_BUTTON_H_
